==> csircd-1.13.tar.gz: csircd-1.13/include/commands.h <==
#ifndef __COMMANDS_H__
#define __COMMANDS_H__

#include "structs.h"

typedef int (*commandfunc_t)(IRCD_CLIENT *lptr, IRCD_CLIENT *ptr, char *prefix, char *args);

int _hunt_server(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *format, int servernum, char *prefix, char *argptr);

int hostname_check(char *hostname);
void _user_del_channels(IRCD_CLIENT *pptr);
void _channel_invite_del(IRCD_CHANNEL *chptr, IRCD_CLIENT *cptr);
int _do_connect(IRCD_CLIENT *pptr, SERVLINK *sptr, int portnum);

int m_privmsg(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_who(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_whois(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_whowas(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_user(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_nick(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_server(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_list(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_topic(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_invite(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_version(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_quit(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_squit(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_kill(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_info(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_links(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_stats(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_help(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_error(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_away(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_connect(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_ping(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_pong(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_oper(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_pass(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_wallops(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_time(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_names(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_admin(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_trace(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_notice(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_join(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_part(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_lusers(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_motd(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_mode(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_kick(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_userhost(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_ison(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_note(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_service(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_squery(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_servlist(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_servset(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_rehash(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_restart(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_close(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_svinfo(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_sjoin(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_die(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_dns(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_gline(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_ext(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_operwall(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_kline(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_set(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_queue(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_flags(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_iphash(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_capab(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_locops(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_rejecthold(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_unkline(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);


#endif

==> csircd-1.14.tar.gz: csircd-1.14/include/commands.h <==
#ifndef __COMMANDS_H__
#define __COMMANDS_H__

#include "structs.h"

typedef int (*commandfunc_t)(IRCD_CLIENT *lptr, IRCD_CLIENT *ptr, char *prefix, char *args);

int _hunt_server(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *format, int servernum, char *prefix, char *argptr);

int username_check(char *username);
int hostname_check(char *hostname);
void _user_del_channels(IRCD_CLIENT *pptr);
void _channel_invite_del(IRCD_CHANNEL *chptr, IRCD_CLIENT *cptr);
int _do_connect(IRCD_CLIENT *pptr, SERVLINK *sptr, int portnum);

int m_privmsg(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_who(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_whois(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_whowas(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_user(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_nick(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_server(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_list(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_topic(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_invite(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_version(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_quit(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_squit(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_kill(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_info(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_links(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_stats(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_help(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_error(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_away(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_connect(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_ping(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_pong(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_oper(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_pass(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_wallops(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_time(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_names(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_admin(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_trace(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_notice(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_join(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_part(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_lusers(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_motd(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_mode(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_kick(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_userhost(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_ison(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_note(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_rehash(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_restart(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_close(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_svinfo(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_sjoin(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_die(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_dns(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_gline(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_encap(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_operwall(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_kline(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_set(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_queue(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_flags(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_iphash(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_capab(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_locops(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_rejecthold(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);
int m_unkline(IRCD_CLIENT *lptr, IRCD_CLIENT *pptr, char *prefix, char *args);


#endif
